==> gamepadinfo-0.8.tar.gz: gamepadinfo-0.8/setup.py <==
# borrowed from: https://github.com/pypa/sampleproject/blob/master/setup.py

from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='gamepadinfo',
    version='0.8',

    description='Detect gamepads and show reads its state on Linux',
    long_description=long_description,
    url='https://github.com/godfryd/gamepadinfo',
    author='Michal Nowikowski',
    author_email='godfryd@gmail.com',
    license='MIT',
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
    ],

    keywords='gamepad gamecontroller joystick',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    #packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    py_modules=["gamepadinfo"],

    install_requires=['urwid', 'pyudev', 'evdev', 'pysdl2'],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        'console_scripts': [
            'gamepadinfo=gamepadinfo:main',
        ],
    },
)

==> gamepadinfo-0.9.1.tar.gz: gamepadinfo-0.9.1/setup.py <==
# borrowed from: https://github.com/pypa/sampleproject/blob/master/setup.py

from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='gamepadinfo',
    version='0.9.1',

    description='Detect gamepads and show reads its state on Linux',
    long_description=long_description,
    url='https://github.com/godfryd/gamepadinfo',
    author='Michal Nowikowski',
    author_email='godfryd@gmail.com',
    license='MIT',
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
    ],

    keywords='gamepad gamecontroller joystick',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    #packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    py_modules=["gamepadinfo"],

    install_requires=['urwid', 'pyudev', 'evdev', 'PySDL2'],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        'console_scripts': [
            'gamepadinfo=gamepadinfo:main',
        ],
    },
)
